

OpticalSystem
==============================

.. currentmodule:: poppy.poppy_core

.. autoclass:: OpticalSystem
   :show-inheritance:

   
     
   

   
   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~OpticalSystem.addDetector
      ~OpticalSystem.addImage
      ~OpticalSystem.addPupil
      ~OpticalSystem.addRotation
      ~OpticalSystem.calcPSF
      ~OpticalSystem.describe
      ~OpticalSystem.display
      ~OpticalSystem.inputWavefront
      ~OpticalSystem.propagate_mono

   
   

   
   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: addDetector
   .. automethod:: addImage
   .. automethod:: addPupil
   .. automethod:: addRotation
   .. automethod:: calcPSF
   .. automethod:: describe
   .. automethod:: display
   .. automethod:: inputWavefront
   .. automethod:: propagate_mono

   
   